Learn R Programming

WRestimates (version 0.1.0)

wr.sigma.sqr: Assumed Population Variance of a Win Ratio

Description

Calculate the assumed population variance of a win ratio. $$\sigma^2 = (4 * (1 + p[tie]))/(3 * k * (1 - k) * (1 - p[tie])$$ Where; $$p[tie] = The proportion of ties.$$ $$k = The proportion of subjects allocated to one group.$$

Usage

wr.sigma.sqr(k, p.tie)

Value

wr.sigma.sqr returns an object of class "list" containing the following components:

sigma.sqr

Population variance of the natural log (\(ln\)) of the win ratio.

k

The proportion of subjects allocated to one group.

p.tie

The proportion of ties.

Arguments

k

The proportion of subjects allocated to one group i.e. the proportion of patients allocated to treatment.

p.tie

The proportion of ties.

Author

Autumn O'Donnell autumn.research@gmail.com

References

Yu, R. X. and Ganju, J. (2022). Sample size formula for a win ratio endpoint. Statistics in medicine, 41(6), 950-963. doi: 10.1002/sim.9297.

See Also

wr.var